==> grimoirejs-cauldron-3.1.2-beta.tgz: package/lib/doc/moajo.js <==
'use strict';

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _typeof2 = require('babel-runtime/helpers/typeof');

var _typeof3 = _interopRequireDefault(_typeof2);

var getTargetFilePathes = function () {
  var _ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee(targetDir) {
    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.next = 2;
            return (0, _asyncHelper.globAsync)(_path2.default.join(targetDir, _yargs.argv.ts ? "**/*.ts" : "**/*.js"));

          case 2:
            return _context.abrupt('return', _context.sent);

          case 3:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, this);
  }));

  return function getTargetFilePathes(_x) {
    return _ref.apply(this, arguments);
  };
}();

var main = function () {
  var _ref2 = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee2() {
    var cwd, projName, grdoc, detectedFiles, i, file, content, doc, key, _key2, _key3;

    return _regenerator2.default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.prev = 0;
            cwd = process.cwd();
            _context2.t0 = JSON;
            _context2.next = 5;
            return (0, _asyncHelper.readFileAsync)(_path2.default.join(cwd, "package.json"));

          case 5:
            _context2.t1 = _context2.sent;
            projName = _context2.t0.parse.call(_context2.t0, _context2.t1).name;
            grdoc = {
              name: projName,
              nodes: {},
              components: {},
              converters: {}
            };
            _context2.next = 10;
            return getTargetFilePathes(_path2.default.join(cwd, _yargs.argv.src));

          case 10:
            detectedFiles = _context2.sent;
            i = 0;

          case 12:
            if (!(i < detectedFiles.length)) {
              _context2.next = 24;
              break;
            }

            file = detectedFiles[i];
            _context2.next = 16;
            return (0, _asyncHelper.readFileAsync)(file);

          case 16:
            content = _context2.sent;
            doc = genDoc(file, content);

            for (key in doc.nodes) {
              grdoc.nodes[key] = doc.nodes[key];
            }
            for (_key2 in doc.components) {
              grdoc.components[_key2] = doc.components[_key2];
            }
            for (_key3 in doc.converters) {
              grdoc.converters[_key3] = doc.converters[_key3];
            }

          case 21:
            i++;
            _context2.next = 12;
            break;

          case 24:
            if (!_yargs.argv.markdown) {
              _context2.next = 34;
              break;
            }

            _context2.t2 = console;
            _context2.t3 = console;
            _context2.next = 29;
            return (0, _toMarkdown2.default)(grdoc);

          case 29:
            _context2.t4 = _context2.sent;
            _context2.t5 = _context2.t3.log.call(_context2.t3, _context2.t4);

            _context2.t2.log.call(_context2.t2, _context2.t5);

            _context2.next = 35;
            break;

          case 34:
            console.log((0, _stringify2.default)(grdoc, null, "\t"));

          case 35:
            _context2.next = 40;
            break;

          case 37:
            _context2.prev = 37;
            _context2.t6 = _context2['catch'](0);

            console.error(_context2.t6);

          case 40:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, this, [[0, 37]]);
  }));

  return function main() {
    return _ref2.apply(this, arguments);
  };
}();

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _jsComments = require('js-comments');

var _jsComments2 = _interopRequireDefault(_jsComments);

var _yargs = require('yargs');

var _asyncHelper = require('../async-helper');

var _toMarkdown = require('./to-markdown');

var _toMarkdown2 = _interopRequireDefault(_toMarkdown);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function getBraceEndPos(source, openPos) {
  var depth = 0;
  for (var i = openPos; i < source.length; i++) {
    if (source[i] == "{") {
      depth++;
      continue;
    }
    if (source[i] == "}") {
      depth--;
    }
    if (depth === 0) {
      return i;
    }
  }
}

function getBraceContent(source, openPos) {
  var end = getBraceEndPos(source, openPos);
  return source.substring(openPos, end + 1);
}

function getIndex(source, line, target) {
  var currentLine = 1;
  for (var i = 0; i < source.length; i++) {
    if (source[i] === "\n") {
      currentLine++;
      continue;
    }
    if (currentLine === line && source[i] === target) {
      return i;
    }
  }
}

function getLine(source, line) {
  return source.split("\n")[line - 1];
}

function checkComponentDec(line) {
  return (/class \w+Component/.test(line)
  );
}

function checkConverterDec(line) {
  return (/function +\w+Converter/.test(line)
  );
}

function checkPathIsComponent(filePath) {
  var cwd = process.cwd();
  var rel = _path2.default.relative(_path2.default.join(cwd, _yargs.argv.src), filePath);
  return !rel.startsWith(".") && filePath.indexOf("/Components/") !== -1 && _path2.default.basename(filePath).indexOf("Component.") !== -1;
}

function checkPathIsConverter(filePath) {
  var cwd = process.cwd();
  var rel = _path2.default.relative(_path2.default.join(cwd, _yargs.argv.src), filePath);
  return !rel.startsWith(".") && filePath.indexOf("/Converters/") !== -1 && _path2.default.basename(filePath).indexOf("Converter.") !== -1;
}

function checkPathIsNode(filePath) {
  var cwd = process.cwd();
  var rel = _path2.default.relative(_path2.default.join(cwd, _yargs.argv.src), filePath);
  return rel.startsWith("nodes.");
}

function findFirstLine(src, predicate) {
  var lines = src.split(/\r\n|\r|\n/);
  for (var i = 0; i < lines.length; i++) {
    if (predicate(lines[i])) {
      return {
        line: i,
        content: lines[i]
      };
    }
  }
  return null;
}

function getSource(src, startLine) {
  var code = getLine(src, startLine);
  var front = code.substring(0, code.indexOf("{"));
  var content = getBraceContent(src, getIndex(src, startLine, "{"));
  return front + content;
}

function genComponentDoc(src) {
  var componentDecs = _jsComments2.default.parse(src).filter(function (c) {
    return checkComponentDec(c.comment.code);
  });
  if (componentDecs.length === 1) {
    // find description comment.
    var c = componentDecs[0];
    var d = parseComponentSource(getSource(src, c.comment.end + 1));
    d.content.description = c.description || "";
    d.content.super = c.super;
    return d;
  } else {
    // no description comment.
    var dec = findFirstLine(src, function (l) {
      return checkComponentDec(l);
    });
    if (dec) {
      var componentSource = getSource(src, dec.line + 1);
      var _d = parseComponentSource(componentSource);
      _d.content.description = "";
      return _d;
    }
  }
}

function parseComponentSource(componentSource) {
  var firstLine = getLine(componentSource, 1);
  var className = firstLine.match(/class +(\w+)/)[1];

  var ret = {
    attributes: {}
  };

  // attribute eval parsing.
  var m = componentSource.search(/static *(?:get)? *(attributes)/gm);
  if (m !== -1) {
    (function () {
      var lastindex = componentSource.indexOf("{", m);
      lastindex = componentSource.indexOf("{", lastindex + 1);

      var a = getBraceContent(componentSource, lastindex);

      // get comments
      var b = {};
      _jsComments2.default.parse(a).forEach(function (obj) {
        var name = obj.comment.code.match(/["']?([\w-]+)["']? *:/)[1];
        b[name] = {
          description: obj.description || ""
        };
      });

      // source eval
      try {
        var atrs = eval('(' + a + ')');
        for (var key in atrs) {
          var aaa = atrs[key];
          var o = {};
          for (var key2 in aaa) {
            o[key2] = String(aaa[key2]);
          }
          o.description = b[key] ? b[key].description : "";
          ret.attributes[key] = o;
        }
      } catch (e) {
        // console.log(e);
        console.warn("attribute cant parse: " + className);
      }
    })();
  }
  return {
    name: className,
    content: ret
  };
}

function genConverterDoc(src) {
  var converterDecs = _jsComments2.default.parse(src).filter(function (c) {
    return checkConverterDec(c.comment.code);
  });
  if (converterDecs.length === 1) {
    var _ret2 = function () {
      // find desc.
      var c = converterDecs[0];
      var d = parseConverterSource(getSource(src, c.comment.end + 1));
      d.content.description = c.description || "";
      d.content.output = c.gr_output;
      d.content.input = c.gr_input;
      d.content.parameters = {};
      if (c.gr_props) {
        c.gr_props.forEach(function (p) {
          d.content.parameters[p.type] = p.description || "";
        });
      }
      return {
        v: d
      };
    }();

    if ((typeof _ret2 === 'undefined' ? 'undefined' : (0, _typeof3.default)(_ret2)) === "object") return _ret2.v;
  } else {
    var dec = findFirstLine(src, function (l) {
      return checkConverterDec(l);
    });
    if (dec) {
      var _d2 = parseConverterSource(getSource(src, dec.line + 1));
      _d2.content.description = "";
      return _d2;
    }
  }
}

function parseConverterSource(converterSrc) {
  var firstLine = getLine(converterSrc, 1);
  var className = firstLine.match(/function +(\w+) *\(/)[1];

  return {
    name: className,
    content: {}
  };
}

function genNodeDoc(src) {
  var nodeDecs = _jsComments2.default.parse(src).filter(function (c) {
    return (/export *default *\{/.test(c.comment.code)
    );
  });
  if (nodeDecs.length === 1) {
    // find desc.
    var c = nodeDecs[0];
    return parseNodeSource(getBraceContent(src, getIndex(src, c.comment.end + 1, "{")));
  } else {
    var dec = findFirstLine(src, function (l) {
      return (/export *default *\{/.test(l)
      );
    });
    if (dec) {
      return parseNodeSource(getBraceContent(src, getIndex(src, dec.line + 1, "{")));
    }
  }
}

function parseNodeSource(nodeSource) {
  var c = _jsComments2.default.parse(nodeSource);
  var descMap = {};
  c.forEach(function (obj) {
    var m = obj.comment.code.match(/["']?([\w-]+)["']? *:/);
    if (m) {
      descMap[m[1]] = obj.description || "";
    }
  });
  var nodeDec = eval('(' + nodeSource + ')');
  var ret = {};
  for (var key in nodeDec) {
    ret[key] = {
      description: descMap[key] || "",
      super: nodeDec[key].super,
      components: nodeDec[key].components,
      default: nodeDec[key].default
    };
  }
  return ret;
}

function genDoc(filePath, sourceCode) {
  try {
    var _ret3 = function () {
      var doc = {
        nodes: {},
        components: {},
        converters: {}
      };
      if (checkPathIsComponent(filePath)) {
        var d = genComponentDoc(sourceCode);
        if (d) {
          doc.components[d.name] = d.content;
        }
      } else if (checkPathIsConverter(filePath)) {
        var _d3 = genConverterDoc(sourceCode);
        if (_d3) {
          doc.converters[_d3.name] = _d3.content;
        }
      } else if (checkPathIsNode(filePath)) {
        var _d4 = genNodeDoc(sourceCode);
        if (_d4) {
          for (var key in _d4) {
            doc.nodes[key] = _d4[key];
          }
        }
      } else {
        var a = _jsComments2.default.parse(sourceCode);
        a.forEach(function (obj) {
          if (obj.gr_component === true) {
            var _d5 = genComponentDoc(sourceCode);
            if (_d5) {
              doc.components[_d5.name] = _d5.content;
            }
          }
          if (obj.gr_converter === true) {
            var _d6 = genConverterDoc(sourceCode);
            if (_d6) {
              doc.converters[_d6.name] = _d6.content;
            }
          }
          if (obj.gr_node === true) {
            var _d7 = genNodeDoc(sourceCode);
            if (_d7) {
              for (var _key in _d7) {
                doc.nodes[_key] = _d7[_key];
              }
            }
          }
        });
      }
      return {
        v: doc
      };
    }();

    if ((typeof _ret3 === 'undefined' ? 'undefined' : (0, _typeof3.default)(_ret3)) === "object") return _ret3.v;
  } catch (e) {
    console.error(e);
  }
}

main();

==> grimoirejs-cauldron-4.1.2-beta.tgz: package/lib/doc/moajo.js <==
'use strict';

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var getTargetFilePathes = function () {
  var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(targetDir) {
    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.next = 2;
            return (0, _asyncHelper.globAsync)(_path2.default.join(targetDir, _yargs.argv.ts ? "**/*.ts" : "**/*.js"));

          case 2:
            return _context.abrupt('return', _context.sent);

          case 3:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, this);
  }));

  return function getTargetFilePathes(_x) {
    return _ref.apply(this, arguments);
  };
}();

var main = function () {
  var _ref2 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee2() {
    var cwd, projName, grdoc, detectedFiles, i, file, content, doc, key, _key2, _key3;

    return _regenerator2.default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.prev = 0;
            cwd = process.cwd();
            _context2.t0 = JSON;
            _context2.next = 5;
            return (0, _asyncHelper.readFileAsync)(_path2.default.join(cwd, "package.json"));

          case 5:
            _context2.t1 = _context2.sent;
            projName = _context2.t0.parse.call(_context2.t0, _context2.t1).name;
            grdoc = {
              name: projName,
              nodes: {},
              components: {},
              converters: {}
            };
            _context2.next = 10;
            return getTargetFilePathes(_path2.default.join(cwd, _yargs.argv.src));

          case 10:
            detectedFiles = _context2.sent;
            i = 0;

          case 12:
            if (!(i < detectedFiles.length)) {
              _context2.next = 24;
              break;
            }

            file = detectedFiles[i];
            _context2.next = 16;
            return (0, _asyncHelper.readFileAsync)(file);

          case 16:
            content = _context2.sent;
            doc = genDoc(file, content);

            for (key in doc.nodes) {
              grdoc.nodes[key] = doc.nodes[key];
            }
            for (_key2 in doc.components) {
              grdoc.components[_key2] = doc.components[_key2];
            }
            for (_key3 in doc.converters) {
              grdoc.converters[_key3] = doc.converters[_key3];
            }

          case 21:
            i++;
            _context2.next = 12;
            break;

          case 24:
            if (!_yargs.argv.markdown) {
              _context2.next = 34;
              break;
            }

            _context2.t2 = console;
            _context2.t3 = console;
            _context2.next = 29;
            return (0, _toMarkdown2.default)(grdoc);

          case 29:
            _context2.t4 = _context2.sent;
            _context2.t5 = _context2.t3.log.call(_context2.t3, _context2.t4);

            _context2.t2.log.call(_context2.t2, _context2.t5);

            _context2.next = 35;
            break;

          case 34:
            console.log((0, _stringify2.default)(grdoc, null, "\t"));

          case 35:
            _context2.next = 40;
            break;

          case 37:
            _context2.prev = 37;
            _context2.t6 = _context2['catch'](0);

            console.error(_context2.t6);

          case 40:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, this, [[0, 37]]);
  }));

  return function main() {
    return _ref2.apply(this, arguments);
  };
}();

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _jsComments = require('js-comments');

var _jsComments2 = _interopRequireDefault(_jsComments);

var _yargs = require('yargs');

var _asyncHelper = require('../async-helper');

var _toMarkdown = require('./to-markdown');

var _toMarkdown2 = _interopRequireDefault(_toMarkdown);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function getBraceEndPos(source, openPos) {
  var depth = 0;
  for (var i = openPos; i < source.length; i++) {
    if (source[i] == "{") {
      depth++;
      continue;
    }
    if (source[i] == "}") {
      depth--;
    }
    if (depth === 0) {
      return i;
    }
  }
}

function getBraceContent(source, openPos) {
  var end = getBraceEndPos(source, openPos);
  return source.substring(openPos, end + 1);
}

function getIndex(source, line, target) {
  var currentLine = 1;
  for (var i = 0; i < source.length; i++) {
    if (source[i] === "\n") {
      currentLine++;
      continue;
    }
    if (currentLine === line && source[i] === target) {
      return i;
    }
  }
}

function getLine(source, line) {
  return source.split("\n")[line - 1];
}

function checkComponentDec(line) {
  return (/class \w+Component/.test(line)
  );
}

function checkConverterDec(line) {
  return (/function +\w+Converter/.test(line)
  );
}

function checkPathIsComponent(filePath) {
  var cwd = process.cwd();
  var rel = _path2.default.relative(_path2.default.join(cwd, _yargs.argv.src), filePath);
  return !rel.startsWith(".") && filePath.indexOf("/Components/") !== -1 && _path2.default.basename(filePath).indexOf("Component.") !== -1;
}

function checkPathIsConverter(filePath) {
  var cwd = process.cwd();
  var rel = _path2.default.relative(_path2.default.join(cwd, _yargs.argv.src), filePath);
  return !rel.startsWith(".") && filePath.indexOf("/Converters/") !== -1 && _path2.default.basename(filePath).indexOf("Converter.") !== -1;
}

function checkPathIsNode(filePath) {
  var cwd = process.cwd();
  var rel = _path2.default.relative(_path2.default.join(cwd, _yargs.argv.src), filePath);
  return rel.startsWith("nodes.");
}

function findFirstLine(src, predicate) {
  var lines = src.split(/\r\n|\r|\n/);
  for (var i = 0; i < lines.length; i++) {
    if (predicate(lines[i])) {
      return {
        line: i,
        content: lines[i]
      };
    }
  }
  return null;
}

function getSource(src, startLine) {
  var code = getLine(src, startLine);
  var front = code.substring(0, code.indexOf("{"));
  var content = getBraceContent(src, getIndex(src, startLine, "{"));
  return front + content;
}

function genComponentDoc(src) {
  var componentDecs = _jsComments2.default.parse(src).filter(function (c) {
    return checkComponentDec(c.comment.code);
  });
  if (componentDecs.length === 1) {
    // find description comment.
    var c = componentDecs[0];
    var d = parseComponentSource(getSource(src, c.comment.end + 1));
    d.content.description = c.description || "";
    d.content.super = c.super;
    return d;
  } else {
    // no description comment.
    var dec = findFirstLine(src, function (l) {
      return checkComponentDec(l);
    });
    if (dec) {
      var componentSource = getSource(src, dec.line + 1);
      var _d = parseComponentSource(componentSource);
      _d.content.description = "";
      return _d;
    }
  }
}

function parseComponentSource(componentSource) {
  var firstLine = getLine(componentSource, 1);
  var className = firstLine.match(/class +(\w+)/)[1];

  var ret = {
    attributes: {}
  };

  // attribute eval parsing.
  var m = componentSource.search(/static *(?:get)? *(attributes)/gm);
  if (m !== -1) {
    var lastindex = componentSource.indexOf("{", m);
    lastindex = componentSource.indexOf("{", lastindex + 1);

    var a = getBraceContent(componentSource, lastindex);

    // get comments
    var b = {};
    _jsComments2.default.parse(a).forEach(function (obj) {
      var name = obj.comment.code.match(/["']?([\w-]+)["']? *:/)[1];
      b[name] = {
        description: obj.description || ""
      };
    });

    // source eval
    try {
      var atrs = eval('(' + a + ')');
      for (var key in atrs) {
        var aaa = atrs[key];
        var o = {};
        for (var key2 in aaa) {
          o[key2] = String(aaa[key2]);
        }
        o.description = b[key] ? b[key].description : "";
        ret.attributes[key] = o;
      }
    } catch (e) {
      // console.log(e);
      console.warn("attribute cant parse: " + className);
    }
  }
  return {
    name: className,
    content: ret
  };
}

function genConverterDoc(src) {
  var converterDecs = _jsComments2.default.parse(src).filter(function (c) {
    return checkConverterDec(c.comment.code);
  });
  if (converterDecs.length === 1) {
    // find desc.
    var c = converterDecs[0];
    var d = parseConverterSource(getSource(src, c.comment.end + 1));
    d.content.description = c.description || "";
    d.content.output = c.gr_output;
    d.content.input = c.gr_input;
    d.content.parameters = {};
    if (c.gr_props) {
      c.gr_props.forEach(function (p) {
        d.content.parameters[p.type] = p.description || "";
      });
    }
    return d;
  } else {
    var dec = findFirstLine(src, function (l) {
      return checkConverterDec(l);
    });
    if (dec) {
      var _d2 = parseConverterSource(getSource(src, dec.line + 1));
      _d2.content.description = "";
      return _d2;
    }
  }
}

function parseConverterSource(converterSrc) {
  var firstLine = getLine(converterSrc, 1);
  var className = firstLine.match(/function +(\w+) *\(/)[1];

  return {
    name: className,
    content: {}
  };
}

function genNodeDoc(src) {
  var nodeDecs = _jsComments2.default.parse(src).filter(function (c) {
    return (/export *default *\{/.test(c.comment.code)
    );
  });
  if (nodeDecs.length === 1) {
    // find desc.
    var c = nodeDecs[0];
    return parseNodeSource(getBraceContent(src, getIndex(src, c.comment.end + 1, "{")));
  } else {
    var dec = findFirstLine(src, function (l) {
      return (/export *default *\{/.test(l)
      );
    });
    if (dec) {
      return parseNodeSource(getBraceContent(src, getIndex(src, dec.line + 1, "{")));
    }
  }
}

function parseNodeSource(nodeSource) {
  var c = _jsComments2.default.parse(nodeSource);
  var descMap = {};
  c.forEach(function (obj) {
    var m = obj.comment.code.match(/["']?([\w-]+)["']? *:/);
    if (m) {
      descMap[m[1]] = obj.description || "";
    }
  });
  var nodeDec = eval('(' + nodeSource + ')');
  var ret = {};
  for (var key in nodeDec) {
    ret[key] = {
      description: descMap[key] || "",
      super: nodeDec[key].super,
      components: nodeDec[key].components,
      default: nodeDec[key].default
    };
  }
  return ret;
}

function genDoc(filePath, sourceCode) {
  try {
    var doc = {
      nodes: {},
      components: {},
      converters: {}
    };
    if (checkPathIsComponent(filePath)) {
      var d = genComponentDoc(sourceCode);
      if (d) {
        doc.components[d.name] = d.content;
      }
    } else if (checkPathIsConverter(filePath)) {
      var _d3 = genConverterDoc(sourceCode);
      if (_d3) {
        doc.converters[_d3.name] = _d3.content;
      }
    } else if (checkPathIsNode(filePath)) {
      var _d4 = genNodeDoc(sourceCode);
      if (_d4) {
        for (var key in _d4) {
          doc.nodes[key] = _d4[key];
        }
      }
    } else {
      var a = _jsComments2.default.parse(sourceCode);
      a.forEach(function (obj) {
        if (obj.gr_component === true) {
          var _d5 = genComponentDoc(sourceCode);
          if (_d5) {
            doc.components[_d5.name] = _d5.content;
          }
        }
        if (obj.gr_converter === true) {
          var _d6 = genConverterDoc(sourceCode);
          if (_d6) {
            doc.converters[_d6.name] = _d6.content;
          }
        }
        if (obj.gr_node === true) {
          var _d7 = genNodeDoc(sourceCode);
          if (_d7) {
            for (var _key in _d7) {
              doc.nodes[_key] = _d7[_key];
            }
          }
        }
      });
    }
    return doc;
  } catch (e) {
    console.error(e);
  }
}

main();
